pub enum ITIP20Events {
Show 14 variants
Transfer(Transfer),
Approval(Approval),
Mint(Mint),
Burn(Burn),
BurnBlocked(BurnBlocked),
TransferWithMemo(TransferWithMemo),
TransferPolicyUpdate(TransferPolicyUpdate),
SupplyCapUpdate(SupplyCapUpdate),
PauseStateUpdate(PauseStateUpdate),
NextQuoteTokenSet(NextQuoteTokenSet),
QuoteTokenUpdate(QuoteTokenUpdate),
RewardDistributed(RewardDistributed),
RewardRecipientSet(RewardRecipientSet),
LogoURIUpdated(LogoURIUpdated),
}Expand description
Container for all the ITIP20 events.
Variants
Transfer(Transfer)
Approval(Approval)
Mint(Mint)
Burn(Burn)
BurnBlocked(BurnBlocked)
TransferWithMemo(TransferWithMemo)
TransferPolicyUpdate(TransferPolicyUpdate)
SupplyCapUpdate(SupplyCapUpdate)
PauseStateUpdate(PauseStateUpdate)
NextQuoteTokenSet(NextQuoteTokenSet)
QuoteTokenUpdate(QuoteTokenUpdate)
RewardDistributed(RewardDistributed)
RewardRecipientSet(RewardRecipientSet)
LogoURIUpdated(LogoURIUpdated)
Implementations
Sourceimpl ITIP20Events
impl ITIP20Events
Sourcepub const SELECTORS: &'static [[u8; 32]]
pub const SELECTORS: &'static [[u8; 32]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20Events
impl ITIP20Events
Sourcepub fn transfer(from: Address, to: Address, amount: U256) -> Self
pub fn transfer(from: Address, to: Address, amount: U256) -> Self
Creates a Transfer event.
event Transfer(address,address,uint256)Sourcepub fn approval(owner: Address, spender: Address, amount: U256) -> Self
pub fn approval(owner: Address, spender: Address, amount: U256) -> Self
Creates a Approval event.
event Approval(address,address,uint256)Sourcepub fn mint(to: Address, amount: U256) -> Self
pub fn mint(to: Address, amount: U256) -> Self
Creates a Mint event.
event Mint(address,uint256)Sourcepub fn burn(from: Address, amount: U256) -> Self
pub fn burn(from: Address, amount: U256) -> Self
Creates a Burn event.
event Burn(address,uint256)Sourcepub fn burn_blocked(from: Address, amount: U256) -> Self
pub fn burn_blocked(from: Address, amount: U256) -> Self
Creates a BurnBlocked event.
event BurnBlocked(address,uint256)Sourcepub fn transfer_with_memo(
from: Address,
to: Address,
amount: U256,
memo: FixedBytes<32>,
) -> Self
pub fn transfer_with_memo( from: Address, to: Address, amount: U256, memo: FixedBytes<32>, ) -> Self
Creates a TransferWithMemo event.
event TransferWithMemo(address,address,uint256,bytes32)Sourcepub fn transfer_policy_update(updater: Address, new_policy_id: u64) -> Self
pub fn transfer_policy_update(updater: Address, new_policy_id: u64) -> Self
Creates a TransferPolicyUpdate event.
event TransferPolicyUpdate(address,uint64)Sourcepub fn supply_cap_update(updater: Address, new_supply_cap: U256) -> Self
pub fn supply_cap_update(updater: Address, new_supply_cap: U256) -> Self
Creates a SupplyCapUpdate event.
event SupplyCapUpdate(address,uint256)Sourcepub fn pause_state_update(updater: Address, is_paused: bool) -> Self
pub fn pause_state_update(updater: Address, is_paused: bool) -> Self
Creates a PauseStateUpdate event.
event PauseStateUpdate(address,bool)Sourcepub fn next_quote_token_set(updater: Address, next_quote_token: Address) -> Self
pub fn next_quote_token_set(updater: Address, next_quote_token: Address) -> Self
Creates a NextQuoteTokenSet event.
event NextQuoteTokenSet(address,address)Sourcepub fn quote_token_update(updater: Address, new_quote_token: Address) -> Self
pub fn quote_token_update(updater: Address, new_quote_token: Address) -> Self
Creates a QuoteTokenUpdate event.
event QuoteTokenUpdate(address,address)Sourcepub fn reward_distributed(funder: Address, amount: U256) -> Self
pub fn reward_distributed(funder: Address, amount: U256) -> Self
Creates a RewardDistributed event.
event RewardDistributed(address,uint256)Sourcepub fn reward_recipient_set(holder: Address, recipient: Address) -> Self
pub fn reward_recipient_set(holder: Address, recipient: Address) -> Self
Creates a RewardRecipientSet event.
event RewardRecipientSet(address,address)Sourcepub fn logo_uri_updated(updater: Address, new_logo_uri: String) -> Self
pub fn logo_uri_updated(updater: Address, new_logo_uri: String) -> Self
Creates a LogoURIUpdated event.
event LogoURIUpdated(address,string)Trait Implementations
Sourceimpl Clone for ITIP20Events
impl Clone for ITIP20Events
Sourcefn clone(&self) -> ITIP20Events
fn clone(&self) -> ITIP20Events
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ITIP20Events
impl Debug for ITIP20Events
Sourceimpl<'de> Deserialize<'de> for ITIP20Events
impl<'de> Deserialize<'de> for ITIP20Events
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Eq for ITIP20Events
Sourceimpl IntoLogData for ITIP20Events
impl IntoLogData for ITIP20Events
Sourcefn to_log_data(&self) -> LogData
fn to_log_data(&self) -> LogData
LogData] object.Sourcefn into_log_data(self) -> LogData
fn into_log_data(self) -> LogData
LogData] object.Sourceimpl PartialEq for ITIP20Events
impl PartialEq for ITIP20Events
Sourcefn eq(&self, other: &ITIP20Events) -> bool
fn eq(&self, other: &ITIP20Events) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ITIP20Events
impl Serialize for ITIP20Events
Sourceimpl SolEventInterface for ITIP20Events
impl SolEventInterface for ITIP20Events
Sourcefn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_raw_log(topics: &[Word], data: &[u8]) -> Result<Self>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
fn decode_log(log: &Log) -> Result<Log<Self>, Error>
impl StructuralPartialEq for ITIP20Events