pub enum ITIP20Calls {
Show 42 variants
name(nameCall),
symbol(symbolCall),
decimals(decimalsCall),
totalSupply(totalSupplyCall),
quoteToken(quoteTokenCall),
nextQuoteToken(nextQuoteTokenCall),
balanceOf(balanceOfCall),
transfer(transferCall),
approve(approveCall),
allowance(allowanceCall),
transferFrom(transferFromCall),
mint(mintCall),
burn(burnCall),
currency(currencyCall),
supplyCap(supplyCapCall),
paused(pausedCall),
transferPolicyId(transferPolicyIdCall),
burnBlocked(burnBlockedCall),
mintWithMemo(mintWithMemoCall),
burnWithMemo(burnWithMemoCall),
transferWithMemo(transferWithMemoCall),
transferFromWithMemo(transferFromWithMemoCall),
changeTransferPolicyId(changeTransferPolicyIdCall),
setSupplyCap(setSupplyCapCall),
pause(pauseCall),
unpause(unpauseCall),
setNextQuoteToken(setNextQuoteTokenCall),
completeQuoteTokenUpdate(completeQuoteTokenUpdateCall),
PAUSE_ROLE(PAUSE_ROLECall),
UNPAUSE_ROLE(UNPAUSE_ROLECall),
ISSUER_ROLE(ISSUER_ROLECall),
BURN_BLOCKED_ROLE(BURN_BLOCKED_ROLECall),
permit(permitCall),
nonces(noncesCall),
DOMAIN_SEPARATOR(DOMAIN_SEPARATORCall),
distributeReward(distributeRewardCall),
setRewardRecipient(setRewardRecipientCall),
claimRewards(claimRewardsCall),
optedInSupply(optedInSupplyCall),
globalRewardPerToken(globalRewardPerTokenCall),
userRewardInfo(userRewardInfoCall),
getPendingRewards(getPendingRewardsCall),
}Expand description
Container for all the ITIP20 function calls.
Variants
name(nameCall)
symbol(symbolCall)
decimals(decimalsCall)
totalSupply(totalSupplyCall)
quoteToken(quoteTokenCall)
nextQuoteToken(nextQuoteTokenCall)
balanceOf(balanceOfCall)
transfer(transferCall)
approve(approveCall)
allowance(allowanceCall)
transferFrom(transferFromCall)
mint(mintCall)
burn(burnCall)
currency(currencyCall)
supplyCap(supplyCapCall)
paused(pausedCall)
transferPolicyId(transferPolicyIdCall)
burnBlocked(burnBlockedCall)
mintWithMemo(mintWithMemoCall)
burnWithMemo(burnWithMemoCall)
transferWithMemo(transferWithMemoCall)
transferFromWithMemo(transferFromWithMemoCall)
changeTransferPolicyId(changeTransferPolicyIdCall)
setSupplyCap(setSupplyCapCall)
pause(pauseCall)
unpause(unpauseCall)
setNextQuoteToken(setNextQuoteTokenCall)
completeQuoteTokenUpdate(completeQuoteTokenUpdateCall)
PAUSE_ROLE(PAUSE_ROLECall)
UNPAUSE_ROLE(UNPAUSE_ROLECall)
ISSUER_ROLE(ISSUER_ROLECall)
BURN_BLOCKED_ROLE(BURN_BLOCKED_ROLECall)
permit(permitCall)
nonces(noncesCall)
DOMAIN_SEPARATOR(DOMAIN_SEPARATORCall)
distributeReward(distributeRewardCall)
setRewardRecipient(setRewardRecipientCall)
claimRewards(claimRewardsCall)
optedInSupply(optedInSupplyCall)
globalRewardPerToken(globalRewardPerTokenCall)
userRewardInfo(userRewardInfoCall)
getPendingRewards(getPendingRewardsCall)
Implementations
Sourceimpl ITIP20Calls
impl ITIP20Calls
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.
Sourceimpl ITIP20Calls
impl ITIP20Calls
Sourcepub fn is_payment(input: &[u8]) -> bool
pub fn is_payment(input: &[u8]) -> bool
Returns true if input matches one of the recognized TIP-20 payment selectors:
transfer/transferWithMemotransferFrom/transferFromWithMemomint/mintWithMemoburn/burnWithMemo
NOTES
- Only validates calldata; the caller must check the TIP-20 address prefix on
to. - Only selector and exact ABI-encoded length match, no decoding (better performance).